@@ -27,7 +27,7 @@ use Lintian::Data;
 use Lintian::Output qw(warning);
 use Lintian::Tags qw(tag);
 use Lintian::Util qw(drain_pipe fail is_string_utf8_encoded open_gz
-  signal_number2name strip);
+  signal_number2name strip normalize_pkg_path);
 use Lintian::SlidingWindow;
 
 my $FONT_PACKAGES = Lintian::Data->new('files/fonts', qr/\s++/);
@@ -1148,6 +1148,14 @@ sub run {
             tag 'override-file-in-wrong-location', $file;
         }
 
+        # doxygen map + md5sum
+        if (   $fname =~ m,^usr/share/doc/$ppkg/[^/]+/.+\.md5$,
+            or $fname =~ m,^usr/share/doc/$ppkg/[^/]+/.+\.map$,) {
+            if($info->index($file->dirname.'doxygen.png')) {
+                tag 'useless-autogenerated-doxygen-file', $file;
+            }
+        }
+
         # ---------------- pyshared-data
         if ($fname=~ m,^usr/share/python-support/$ppkg\.(?:public|private)$,){
             $py_support_nver = '(>= 0.90)';
